@@ -1,19 +1,17 @@
 """``runway gen-sample cdk-tsc`` command."""
 import logging
-import sys
-from typing import Any  # pylint: disable=W
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, cast
 
 import click
 
 from ... import options
 from .utils import TEMPLATES, copy_sample
 
-if sys.version_info.major > 2:
-    from pathlib import Path  # pylint: disable=E
-else:
-    from pathlib2 import Path  # pylint: disable=E
+if TYPE_CHECKING:
+    from ...._logging import RunwayLogger
 
-LOGGER = logging.getLogger(__name__.replace("._", "."))
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__.replace("._", ".")))
 
 
 @click.command("cdk-tsc", short_help="cdk + tsc (sampleapp.cdk)")
@@ -21,8 +19,7 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.no_color
 @options.verbose
 @click.pass_context
-def cdk_tsc(ctx, **_):
-    # type: (click.Context, Any) -> None
+def cdk_tsc(ctx: click.Context, **_: Any) -> None:
     """Generate a sample AWS CDK project using TypeScript."""
     src = TEMPLATES / "cdk-tsc"
     dest = Path.cwd() / "sampleapp.cdk"
