@@ -40,8 +40,8 @@ class Cluster(Blueprint):
     def create_template(self) -> None:
         """Create template (main function called by CFNgin)."""
         template = self.template
-        template.add_version("2010-09-09")
-        template.add_description("Kubernetes Master via EKS - V1.0.0")
+        template.set_version("2010-09-09")
+        template.set_description("Kubernetes Master via EKS - V1.0.0")
 
         # Resources
         ccpsecuritygroup = template.add_resource(
