@@ -747,7 +747,7 @@ class SourceProcessor:
         """
         # only loading git here when needed to avoid load errors on systems
         # without git installed
-        from git import Repo  # pylint: disable=import-outside-toplevel
+        from git.repo import Repo  # pylint: disable=import-outside-toplevel
 
         ref = self.determine_git_ref(config)
         dir_name = self.sanitize_git_path(uri=config.uri, ref=ref)
@@ -765,7 +765,7 @@ class SourceProcessor:
             try:
                 tmp_repo_path = os.path.join(tmp_dir, dir_name)
                 with Repo.clone_from(config.uri, tmp_repo_path) as repo:
-                    repo.head.reference = ref
+                    repo.head.set_reference(ref)
                     repo.head.reset(index=True, working_tree=True)
                 shutil.move(tmp_repo_path, self.package_cache_dir)
             finally:
