@@ -509,9 +509,9 @@ class UploadRequestSubmitter(BaseTransferRequestSubmitter):
         """Warn if too large."""
         if fileinfo.size and fileinfo.size > MAX_UPLOAD_SIZE:
             file_path = relative_path(fileinfo.src)
-            warning_message = "File %s exceeds s3 upload limit of %s." % (
-                file_path,
-                human_readable_size(MAX_UPLOAD_SIZE),
+            warning_message = (
+                f"File {file_path} exceeds s3 upload limit of "
+                f"{human_readable_size(MAX_UPLOAD_SIZE)}."
             )
             warning = create_warning(file_path, warning_message, skip_file=False)
             self._result_queue.put(warning)
@@ -843,9 +843,7 @@ class LocalDeleteRequestSubmitter(BaseTransferRequestSubmitter):
             self._result_queue.put(SuccessResult(**result_kwargs))
         except Exception as exc:  # pylint: disable=broad-except
             self._result_queue.put(FailureResult(exception=exc, **result_kwargs))
-        finally:
-            # Return True to indicate that the transfer was submitted
-            return True  # pylint: disable=lost-exception
+        return True
 
     def _format_src_dest(
         self, fileinfo: FileInfo
