@@ -1,8 +1,12 @@
 """Serverless Hello World function."""
+from __future__ import annotations
+
 import json
+from typing import Any, Dict, Union
 
 
-def handler(event, context):  # pylint: disable=unused-argument
+# pylint: disable=unused-argument
+def handler(event: Any, context: Any) -> Dict[str, Union[int, str]]:
     """Return Serverless Hello World."""
     body = {
         "message": "Go Serverless v1.0! Your function executed successfully!",
